<?php

/**
 * @package     SnoS - Cookie Consent
 * @version     1.0.1
 * @author      SnoS <info@snos.nl>
 * @link        https://www.snos.nl
 * @copyright   Copyright (C) 2025 SnoS. All rights reserved.
 * @license     GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
 */

defined('_JEXEC') or die;

// Laad het CSS-bestand
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;

$doc = Factory::getDocument();
$doc->addStyleSheet(JURI::base() . 'modules/mod_cookie_consent/mod_cookie_consent.css');

// Verkrijg parameters
$message = $params->get('message', 'We use cookies to improve your experience.');
$buttonText = $params->get('button_text', 'Accept cookies');
$rejectButtonText = $params->get('reject_button_text', 'Reject cookies');
$rejectButtonUrl = $params->get('reject_button_url', 'https://example.com');
$policyUrl = $params->get('cookie_policy', '');

?>

<center>
<div id="cookie-banner-overlay" class="cookie-banner-overlay">
    <div id="cookie-banner" class="cookie-banner">
        <p><H2><?php echo Text::_('MOD_COOKIE_CONSENT_TITLE'); ?></H2></p><br>
        <p><?php echo htmlspecialchars($message); ?></p>

        <?php if ($policyUrl): ?>
                <a href="<?php echo htmlspecialchars($policyUrl); ?>" target="_blank">
                    <?php echo Text::_('MOD_COOKIE_CONSENT_COOKIE_POLICY_LINK_TEXT'); ?>
                </a><br>
        <?php endif; ?>

        <button id="accept-cookies"><?php echo htmlspecialchars($buttonText); ?></button>
        <?php if ($rejectButtonText): ?>
            <button id="reject-cookies" data-url="<?php echo htmlspecialchars($rejectButtonUrl); ?>">
                <?php echo htmlspecialchars($rejectButtonText); ?>
            </button>
        <?php endif; ?>
    </div>
</div>
</center>

<script>
    document.addEventListener('DOMContentLoaded', function () {
        const overlay = document.getElementById('cookie-banner-overlay');
        const acceptButton = document.getElementById('accept-cookies');
        const rejectButton = document.getElementById('reject-cookies');

        // Controleer of cookies al zijn geaccepteerd
        if (localStorage.getItem('cookiesAccepted')) {
            overlay.style.display = 'none';
        }

        // Als er op accepteren wordt geklikt
        if (acceptButton) {
            acceptButton.addEventListener('click', function () {
                localStorage.setItem('cookiesAccepted', 'true');
                overlay.style.display = 'none';
            });
        }

        // Als er op afwijzen wordt geklikt
        if (rejectButton) {
            rejectButton.addEventListener('click', function () {
                const url = rejectButton.getAttribute('data-url');
                window.location.href = url;
            });
        }
    });
</script>

<?php
defined('_JEXEC') or die;

// Verkrijg parameters
$message = $params->get('message', 'We gebruiken cookies om je ervaring te verbeteren.');
$buttonText = $params->get('button_text', 'Accepteer cookies');
$rejectButtonText = $params->get('reject_button_text', 'Afwijzen');
$rejectButtonUrl = $params->get('reject_button_url', 'https://example.com');
$policyLinkType = $params->get('policy_link_type', 'url');
$policyLink = $params->get('cookie_policy', '');
$policyArticleId = $params->get('policy_article_id', '');
?>
